Module diff
mcp_rtk
1.6.0
Module diff
Module Items
Functions
In crate mcp_
rtk
mcp_rtk
Module
diff
Side-by-side diff display for raw vs filtered tool responses.
Functions

print_
diff
Display a colored diff between raw and filtered JSON strings.